==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-cpuload/cpuload_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation type="vanished">Vytížení procesoru %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="124"/>
        <source>CPU load %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation type="vanished">Nastavení vytížení procesoru v LXQtu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Ukázat text</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Obnovovací interval:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Směr pruhu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Bottom up</source>
        <translation>Zdola nahoru</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Top down</source>
        <translation>Shora dolů</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="72"/>
        <source>Left to right</source>
        <translation>Zleva doprava</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="73"/>
        <source>Right to left</source>
        <translation>Zprava doleva</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation>Vytížení procesoru %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>Vytížení procesoru %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation>Nastavení vytížení procesoru v LXQtu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Nastavení vytížení procesoru</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Ukázat text</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Obnovovací interval:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Směr pruhu</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Šířka pruhu:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Zdola nahoru</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Shora dolů</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Zleva doprava</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Zprava doleva</translation>
    </message>
</context>
</TS>
